@@ -23,7 +23,6 @@ Kenozooid's logbook command line user interface.
 
 import sys
 import itertools
-import os
 import os.path
 from functools import partial
 from lxml import etree as et
@@ -229,7 +228,7 @@ class AddDiveSite(object):
         fout = args.output[0]
 
         if os.path.exists(fout):
-            doc = et.parse(fout).getroot()
+            doc = ku.parse(fout).getroot()
         else:
             doc = ku.create()
 
@@ -274,7 +273,7 @@ class ListDiveSites(object):
         files = args.input
 
         for fin in files:
-            nodes = ku.parse(fin, query, site=args.site)
+            nodes = ku.find(fin, query, site=args.site)
             print('{}:'.format(fin))
             for i, n in enumerate(nodes):
                 n = ku.site_data(n)
@@ -316,16 +315,10 @@ class DelDiveSite(object):
 
         query = ku.XP_FIND_SITE
         fin = args.input[0]
-        fbk = '{}.bak'.format(fin)
 
-        doc = et.parse(fin)
+        doc = ku.parse(fin)
         ku.remove_nodes(doc, query, site=args.site[0])
-        os.rename(fin, fbk)
-        try:
-            ku.save(doc.getroot(), fin)
-        except Exception as ex:
-            os.rename(fbk, fin)
-            raise ex
+        ku.save(doc.getroot(), fin)
 
 
 
@@ -373,7 +366,7 @@ class AddBuddy(object):
         fout = args.output[0]
 
         if os.path.exists(fout):
-            doc = et.parse(fout).getroot()
+            doc = ku.parse(fout).getroot()
         else:
             doc = ku.create()
 
@@ -420,7 +413,7 @@ class ListBuddies(object):
         files = args.input
 
         for fin in files:
-            nodes = ku.parse(fin, query, buddy=args.buddy)
+            nodes = ku.find(fin, query, buddy=args.buddy)
             print('{}:'.format(fin))
             for i, n in enumerate(nodes):
                 b = ku.buddy_data(n)
@@ -456,16 +449,10 @@ class DelBuddy(object):
 
         query = ku.XP_FIND_BUDDY
         fin = args.input[0]
-        fbk = '{}.bak'.format(fin)
 
-        doc = et.parse(fin)
+        doc = ku.parse(fin)
         ku.remove_nodes(doc, query, buddy=args.buddy[0])
-        os.rename(fin, fbk)
-        try:
-            ku.save(doc.getroot(), fin)
-        except Exception as ex:
-            os.rename(fbk, fin)
-            raise ex
+        ku.save(doc.getroot(), fin)
 
 
 @inject(CLIModule, name='upgrade')
@@ -493,15 +480,11 @@ class DelBuddy(object):
         import kenozooid.logbook as kl
 
         for fin in args.input:
-            fbk = '{}.bak'.format(fin)
-
-            os.rename(fin, fbk)
             try:
-                log.info('Upgraded {}'.format(fin))
-                doc = kl.upgrade_file(open(fbk))
+                print('Upgrading {}'.format(fin))
+                doc = kl.upgrade_file(fin)
                 ku.save(doc.getroot(), fin)
             except Exception as ex:
-                os.rename(fbk, fin)
                 print('Cannot upgrade file {}'.format(fin), file=sys.stderr)
                 print('Error: {}'.format(ex))
 
