@@ -26,6 +26,8 @@ from io import BytesIO
 from datetime import datetime
 from functools import partial
 from dirty.xml import xml
+import tempfile
+import shutil
 import unittest
 
 import kenozooid.uddf as ku
@@ -70,6 +72,7 @@ UDDF_PROFILE = b"""\
             <depth>1.48</depth>
             <divetime>0</divetime>
             <temperature>289.02</temperature>
+            <divemode type='opencircuit'/>
           </waypoint>
           <waypoint>
             <depth>2.43</depth>
@@ -97,6 +100,7 @@ UDDF_PROFILE = b"""\
             <depth>2.61</depth>
             <divetime>0</divetime>
             <temperature>296.73</temperature>
+            <divemode type='closedcircuit'/>
           </waypoint>
           <waypoint>
             <depth>4.18</depth>
@@ -265,6 +269,7 @@ class FindDataTestCase(unittest.TestCase):
         self.assertEquals(30.2, dive.depth)
         self.assertEquals(251.4, dive.temp)
         self.assertEquals(10.1, dive.avg_depth)
+        self.assertEquals('opencircuit', dive.mode)
 
 
     def test_profile_data(self):
@@ -382,24 +387,6 @@ class CreateDataTestCase(unittest.TestCase):
         self.assertEquals(ku.FMT_DT(now), dt)
 
 
-    def test_save(self):
-        """
-        Test UDDF data saving
-        """
-        doc = ku.create()
-        f = BytesIO()
-        ku.save(doc, f)
-        s = f.getvalue()
-        self.assertFalse(b'uddf:' in s)
-        f.close() # check if file closing is possible
-
-        preamble = b"""\
-<?xml version='1.0' encoding='UTF-8'?>
-<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">\
-"""
-        self.assertTrue(s.startswith(preamble), s)
-
-
     def test_set_data(self):
         """
         Test generic method for creating XML data
@@ -720,6 +707,23 @@ class CreateDataTestCase(unittest.TestCase):
         self.assertEquals(r, 'Test 1', sd)
 
 
+    def test_create_dive(self):
+        """
+        Test UDDF dive creation
+        """
+        samples = (kd.Sample(depth=3.1, time=19, temp=20),)
+        d = kd.Dive(datetime=datetime(2012, 2, 25), depth=32.5,
+                duration=45, profile=samples)
+        dive = ku.create_dive(d)
+
+        n, sd = xml2et(xml.dive(dive))
+
+        self.assertEquals('19', ku.xp_first(n, '//divetime/text()'), sd)
+        self.assertEquals('3.1', ku.xp_first(n, '//depth/text()'), sd)
+        self.assertEquals('20.0', ku.xp_first(n, '//temperature/text()'), sd)
+        self.assertEquals(None, ku.xp_first(n, '//divemode/@type'), sd)
+
+
     def test_create_dive_samples(self):
         """
         Test UDDF dive profile sample creation
@@ -730,6 +734,7 @@ class CreateDataTestCase(unittest.TestCase):
         self.assertEquals('19', ku.xp_first(n, '//divetime/text()'), sd)
         self.assertEquals('3.1', ku.xp_first(n, '//depth/text()'), sd)
         self.assertEquals('20.0', ku.xp_first(n, '//temperature/text()'), sd)
+        self.assertEquals(None, ku.xp_first(n, '//divemode/@type'), sd)
 
 
     def test_create_dive_samples_deco_alarm(self):
@@ -746,12 +751,31 @@ class CreateDataTestCase(unittest.TestCase):
         """
         Test UDDF dive profile sample creation with setpoint
         """
-        s = kd.Sample(depth=3.1, time=19, temp=20, setpoint=1.17,
-                setpointby='user'),
+        s = (kd.Sample(depth=3.1, time=19, temp=20, setpoint=1.17,
+                setpointby='user'),)
         samples = ku.create_dive_samples(s)
         n, sd = xml2et(xml.dive(samples))
         self.assertEquals('1.17', ku.xp_first(n, '//setpo2/text()'), sd)
         self.assertEquals('user', ku.xp_first(n, '//setpo2/@setby'), sd)
+
+
+    def test_create_dive_samples_dive_mode(self):
+        """
+        Test UDDF dive profile sample creation with dive mode
+        """
+        s = (kd.Sample(depth=3.1, time=19, temp=20),
+                kd.Sample(depth=3.3, time=29, temp=20),)
+        samples = ku.create_dive_samples(s, 'opencircuit')
+        n, sd = xml2et(xml.dive(samples))
+        modes = list(ku.xp(n, '//divemode/@type'))
+        self.assertEquals(['opencircuit'], modes)
+
+        s = (kd.Sample(depth=3.1, time=19, temp=20),
+                kd.Sample(depth=3.3, time=29, temp=20),)
+        samples = ku.create_dive_samples(s, 'closedcircuit')
+        n, sd = xml2et(xml.dive(samples))
+        modes = list(ku.xp(n, '//divemode/@type'))
+        self.assertEquals(['closedcircuit'], modes)
         
 
     def test_dump_data_encode(self):
@@ -1352,4 +1376,65 @@ class NodeCopyTestCase(unittest.TestCase):
         self.assertTrue(ku.xp_first(t, '//uddf:c') is not None)
 
 
+
+class UDDFSaveTestCase(unittest.TestCase):
+    def setUp(self):
+        """
+        Create temporary directory to store test files.
+        """
+        self.tdir = tempfile.mkdtemp()
+
+
+    def tearDown(self):
+        """
+        Destroy temporary directory with test files.
+        """
+        shutil.rmtree(self.tdir)
+
+
+    def test_save_bytes_io(self):
+        """
+        Test UDDF data saving to BytesIO object
+        """
+        doc = ku.create()
+        f = BytesIO()
+        ku.save(doc, f)
+        s = f.getvalue()
+        self.assertFalse(b'uddf:' in s)
+        f.close() # check if file closing is possible
+
+        preamble = b"""\
+<?xml version='1.0' encoding='UTF-8'?>
+<uddf xmlns="http://www.streit.cc/uddf/3.1/" version="3.1.0">\
+"""
+        self.assertTrue(s.startswith(preamble), s)
+
+
+    def test_save_filename(self):
+        """
+        Test saving to an UDDF file
+        """
+        f = '{}/save_test.uddf'.format(self.tdir)
+
+        doc = ku.create()
+        ku.create_site_data(doc, id='s1', location='L1', name='N1')
+        ku.save(doc, f)
+        data = open(f, 'r').read(10)
+        self.assertEquals('<?xml vers', data)
+
+
+    def test_save_bz2_filename(self):
+        """
+        Test saving to an UDDF file compressed with bzip2
+        """
+        f = '{}/save_test.uddf.bz2'.format(self.tdir)
+
+        doc = ku.create()
+        ku.create_site_data(doc, id='s1', location='L1', name='N1')
+        ku.save(doc, f)
+
+        data = open(f, 'rb').read(3)
+        self.assertEquals(b'BZh', data)
+
+
 # vim: sw=4:et:ai
