@@ -100,7 +100,9 @@ XP_DEFAULT_DIVE_DATA = (
     XPath('uddf:informationafterdive/uddf:greatestdepth/text()'),
     XPath('uddf:informationafterdive/uddf:diveduration/text()'),
     XPath('uddf:informationafterdive/uddf:lowesttemperature/text()'),
-    XPath('uddf:informationafterdive/uddf:averagedepth/text()'))
+    XPath('uddf:informationafterdive/uddf:averagedepth/text()'),
+    XPath('uddf:samples/uddf:waypoint/uddf:divemode[1]/@type'),
+)
 
 # XPath queries for default dive profile sample data
 XP_DEFAULT_PROFILE_DATA =  (
@@ -371,9 +373,9 @@ def dive_data(node, fields=None, queries=None, parsers=None):
     .. seealso:: :py:func:`find_data`
     """
     if fields is None:
-        fields = ('datetime', 'depth', 'duration', 'temp', 'avg_depth')
+        fields = ('datetime', 'depth', 'duration', 'temp', 'avg_depth', 'mode')
         queries = XP_DEFAULT_DIVE_DATA
-        parsers = (dparse, float, float, float, float)
+        parsers = (dparse, float, float, float, float, str)
 
     return find_data('Dive', node, fields, queries, parsers)
 
@@ -987,7 +989,7 @@ def create_dive(dive, equipment=None):
             .format(dive))
     return xml.dive(
         xml.informationbeforedive(xml.datetime(FMT_DT(dive.datetime))),
-        xml.samples(create_dive_samples(dive.profile)),
+        xml.samples(create_dive_samples(dive.profile, dive.mode)),
         xml.informationafterdive(
             xml.greatestdepth(FMT_F(dive.depth)),
             xml.diveduration(FMT_I(dive.duration)),
@@ -999,15 +1001,17 @@ def create_dive(dive, equipment=None):
     )
 
 
-def create_dive_samples(samples):
+def create_dive_samples(samples, mode=None):
     """
     Create dive samples UDDF XML data.
 
     :Parameters:
      samples
         Iterable of tuples of dive samples.
+     mode
+        Dive mode, i.e. opencircuit, closedcircuit.
     """
-    for s in samples:
+    for i, s in enumerate(samples):
         yield xml.waypoint(
             None if s.alarm is None else (xml.alarm(a) for a in s.alarm),
             None if s.deco_time is None else
@@ -1022,6 +1026,7 @@ def create_dive_samples(samples):
                 setby=s.setpointby),
             None if s.gas is None else xml.switchmix(ref=str(s.gas.id)),
             None if s.temp is None else xml.temperature(FMT_F(s.temp)),
+            None if mode is None or i > 0 else xml.divemode(type=mode),
         )
 
 
@@ -1105,7 +1110,7 @@ def save(doc, fout, validate=True):
         os.rename(fout, fbk)
         log.debug('backup file created')
     try:
-        f = openf(fout, 'w') if is_fn else fout
+        f = openf(fout, 'wb') if is_fn else fout
 
         if et.iselement(doc):
             et.ElementTree(doc).write(f,
